==> touhoulittlemaid-fabric-1.21.1-0.0.2-neo1.2.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/renderer/tileentity/TileEntityAltarRenderer.java <==
package com.github.tartaricacid.touhoulittlemaid.client.renderer.tileentity;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.client.model.AltarModel;
import com.github.tartaricacid.touhoulittlemaid.tileentity.TileEntityAltar;
import com.github.tartaricacid.touhoulittlemaid.util.RenderHelper;
import net.minecraft.class_1799;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_5614;
import net.minecraft.class_7833;
import net.minecraft.class_811;
import net.minecraft.class_827;

public class TileEntityAltarRenderer implements class_827<TileEntityAltar> {
    private static final class_2960 TEXTURE = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "textures/entity/altar.png");
    private final AltarModel MODEL;

    public TileEntityAltarRenderer(class_5614.class_5615 render) {
        MODEL = new AltarModel(render.method_32140(AltarModel.LAYER));
    }

    @Override
    public void render(TileEntityAltar te, float partialTicks, class_4587 poseStack, class_4597 bufferIn, int combinedLightIn, int combinedOverlayIn) {
        if (te.isRender()) {
            poseStack.method_22903();
            this.setTranslateAndPose(te, poseStack);
            poseStack.method_22907(class_7833.field_40717.rotationDegrees(180));
            class_4588 buffer = bufferIn.getBuffer(class_1921.method_23580(TEXTURE));
            MODEL.method_60879(poseStack, buffer, combinedLightIn, combinedOverlayIn);
            poseStack.method_22909();
        }

        if (te.isCanPlaceItem() && !te.handler.getStackInSlot(0).method_7960()) {
            class_1799 stack = te.handler.getStackInSlot(0);
            poseStack.method_22903();
            poseStack.method_22904(0.5, 1.25, 0.5);
            class_310.method_1551().method_1480().method_23178(stack, class_811.field_4318, combinedLightIn, combinedOverlayIn, poseStack, bufferIn, te.method_10997(), 0);
            poseStack.method_22909();
        }
    }

    @Override
    public boolean shouldRenderOffScreen(TileEntityAltar te) {
        return true;
    }

    private void setTranslateAndPose(TileEntityAltar te, class_4587 poseStack) {
        switch (te.getDirection()) {
            case field_11035:
                poseStack.method_22904(1, -1.5, -3);
                poseStack.method_22907(class_7833.field_40716.rotationDegrees(180));
                break;
            case field_11034:
                poseStack.method_22904(-3, -1.5, 0);
                poseStack.method_22907(class_7833.field_40716.rotationDegrees(270));
                break;
            case field_11039:
                poseStack.method_22904(4, -1.5, 1);
                poseStack.method_22907(class_7833.field_40716.rotationDegrees(90));
                break;
            case field_11043:
            default:
                poseStack.method_22904(0, -1.5, 4);
        }
    }

    // TODO
/*    @Override
    public AABB getRenderBoundingBox(TileEntityAltar te) {
        return RenderHelper.getAABB(te.getWorldPosition().offset(-9, -5, -9), te.getWorldPosition().offset(9, 5, 9));
    }*/
}

==> touhoulittlemaid-fabric-1.21.1-0.0.6-neo1.3.6-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/renderer/tileentity/TileEntityAltarRenderer.java <==
package com.github.tartaricacid.touhoulittlemaid.client.renderer.tileentity;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.client.model.bedrock.SimpleBedrockModel;
import com.github.tartaricacid.touhoulittlemaid.client.resource.BedrockModelLoader;
import com.github.tartaricacid.touhoulittlemaid.tileentity.TileEntityAltar;
import net.minecraft.class_1297;
import net.minecraft.class_1799;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_5614;
import net.minecraft.class_7833;
import net.minecraft.class_811;
import net.minecraft.class_827;

public class TileEntityAltarRenderer implements class_827<TileEntityAltar> {
    private static final class_2960 TEXTURE = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "textures/bedrock/block/altar.png");
    private final SimpleBedrockModel<? extends class_1297> model;

    public TileEntityAltarRenderer(class_5614.class_5615 render) {
        this.model = BedrockModelLoader.getModel(BedrockModelLoader.ALTAR);
    }

    @Override
    public void render(TileEntityAltar te, float partialTicks, class_4587 poseStack, class_4597 bufferIn, int combinedLightIn, int combinedOverlayIn) {
        if (te.isRender()) {
            poseStack.method_22903();
            this.setTranslateAndPose(te, poseStack);
            poseStack.method_22907(class_7833.field_40717.rotationDegrees(180));
            class_4588 buffer = bufferIn.getBuffer(class_1921.method_23580(TEXTURE));
            model.method_60879(poseStack, buffer, combinedLightIn, combinedOverlayIn);
            poseStack.method_22909();
        }

        if (te.isCanPlaceItem() && !te.handler.getStackInSlot(0).method_7960()) {
            class_1799 stack = te.handler.getStackInSlot(0);
            poseStack.method_22903();
            double time = (System.currentTimeMillis() + te.method_11016().method_10063()) % 3600;
            poseStack.method_22904(0.5, 1.25 + Math.sin(time / 1800 * Math.PI) * 0.1, 0.5);
            poseStack.method_22907(class_7833.field_40716.rotationDegrees((float) time / 10));
            class_310.method_1551().method_1480().method_23178(stack, class_811.field_4318, combinedLightIn, combinedOverlayIn, poseStack, bufferIn, te.method_10997(), 0);
            poseStack.method_22909();
        }
    }

    @Override
    public boolean shouldRenderOffScreen(TileEntityAltar te) {
        return true;
    }

    private void setTranslateAndPose(TileEntityAltar te, class_4587 poseStack) {
        switch (te.getDirection()) {
            case field_11035:
                poseStack.method_22904(1, -1.5, -3);
                poseStack.method_22907(class_7833.field_40716.rotationDegrees(180));
                break;
            case field_11034:
                poseStack.method_22904(-3, -1.5, 0);
                poseStack.method_22907(class_7833.field_40716.rotationDegrees(270));
                break;
            case field_11039:
                poseStack.method_22904(4, -1.5, 1);
                poseStack.method_22907(class_7833.field_40716.rotationDegrees(90));
                break;
            case field_11043:
            default:
                poseStack.method_22904(0, -1.5, 4);
        }
    }

    // TODO
//    @Override
//    public AABB getRenderBoundingBox(TileEntityAltar te) {
//        return RenderHelper.getAABB(te.getWorldPosition().offset(-9, -5, -9), te.getWorldPosition().offset(9, 5, 9));
//    }
}
